==> KleckFiles(5.80.00).zip: KleckFiles/wiki/page/project/cmdline.js <==
var wikiMetaData = {created:'230808', modified:'230815'}; // tag data-change-note='230808/13:23/Note here'
var wikiFileText = [
"<h1>Command-line Options</h1>",
"<p>In your browser address bar, after the 'wiki.html' filename, the command-line begins with a ? char. Cmd-line parameters are separated by &amp; chars.",
"<br>Browser address bar example: <a href=\"wiki.html?bk=pl&cmdline\" target=\"_blank\">wiki.html?bk=pl&cmdline</a>",
"",
"<ul>",
"<li><b>Select book:</b> book|bk|b|@=book_id|book_idx|book_name, @book_id, @book_idx, book_idx",
"    <br>Example 1: <a href=\"wiki.html?book=pl\" target=\"_blank\">wiki.html?book=pl</a>",
"    <br>Example 2: <a href=\"wiki.html?bk=PL\" target=\"_blank\">wiki.html?bk=PL</a>",
"    <br>Example 3: <a href=\"wiki.html?b=2\" target=\"_blank\">wiki.html?b=2</a>",
"    <br>Example 4: <a href=\"wiki.html?@2\" target=\"_blank\">wiki.html?@2</a>",
"    <br>Example 5: <a href=\"wiki.html?2\" target=\"_blank\">wiki.html?2</a>",
"<br>Tip: If no book specified, default book \"kleckfiles\" is opened.",
"</li>",
"<li><b>Select page:</b> page=pageId, pageId",
"  <br>Example 1: <a href=\"wiki.html?@pl&page=cmdline\" target=\"_blank\">wiki.html?@pl&page=cmdline</a>",
"  <br>Example 2: <a href=\"wiki.html?@pl&cmdline\" target=\"_blank\">wiki.html?@pl&cmdline</a>",
"  <br>Tip: pageId is the page filename without the .js file extension. ",
"<br>You can view the file path by hovering the mouse over TOC item or going to the edit page.",
"</li>",
"<li><b>Go to page: </b>keywords available : edit|chat|books|search",
"  <br>Example 1: <a href=\"wiki.html?@pl&edit\" target=\"_blank\">wiki.html?@pl&edit</a>",
"  <br>Example 2: <a href=\"wiki.html?@pl&chat\" target=\"_blank\">wiki.html?@pl&chat</a>",
"  <br>Example 3: <a href=\"wiki.html?@pl&books\" target=\"_blank\">wiki.html?@pl&books</a>",
"  <br>Example 3: <a href=\"wiki.html?@pl&search\" target=\"_blank\">wiki.html?@pl&search</a>",
"</li>",
"<li><b>Jump to bookmark: </b>jump=control_id",
"  <br>Example: <a href=\"wiki.html?bk=pl&codePage&jump=tocItem_4\" target=\"_blank\">wiki.html?bk=pl&codePage&jump=tocItem_4</a>",
"  <br>Jumps you to a control/section with that Id. Ctrl+click jump table (TOC) items to create a url containing the jump= link (opens in new tab).",
"</li>",
"<li><b>Search: </b>search=text, Use %20 for space in text if browser requires it. '2::text' to search book 2 for text. '*::text' to search all books for text. '*::' lists all pages in all books sorted by date modified, no text search, ",
"  <br>Example: <a href=\"wiki.html?search=lord\" target=\"_blank\">wiki.html?search=lord</a> - open default book and search for text",
"  <br>Example: <a href=\"wiki.html?search=2::lord\" target=\"_blank\">wiki.html?search=2::lord</a> - open default book and search book 2",
"  <br>Example: <a href=\"wiki.html?search=*::lord\" target=\"_blank\">wiki.html?search=*::lord</a> - open default book and search all books",
"  <br>Example: <a href=\"wiki.html?search=*::\" target=\"_blank\">wiki.html?search=*::</a> - open default book and list all files by date modified",
"  <br>Example: <a href=\"wiki.html?2&search=2::lord\" target=\"_blank\">wiki.html?2&search=2::lord</a> - open book 2 and search book 2",
"  <br>Example: <a href=\"wiki.html?2&search=lord\" target=\"_blank\">wiki.html?2&search=lord</a> - open book 2 and search (book 2)",
"  <br>",
"</li>",
"</ul>"
];

==> KleckFiles(6.39.00).zip: KleckFiles/wiki/page/project/cmdline.js <==
var wikiMetaData = {created:'230808', modified:'230815'}; // tag data-change-note='230808/13:23/Note here'
var wikiFileText = [
"<h1>Command-line Options</h1>",
"<p>In your browser address bar, after the 'wiki.html' filename, the command-line begins with a ? char. Cmd-line parameters are separated by &amp; chars.",
"<br>Browser address bar example: <a href=\"wiki.html?bk=pl&cmdline\" target=\"_blank\">wiki.html?bk=pl&cmdline</a>",
"",
"<ul>",
"<li><b>Select book:</b> book|bk|b|@=book_id|book_idx|book_name, @book_id, @book_idx, book_idx",
"    <br>Example 1: <a href=\"wiki.html?book=1\" target=\"_blank\">wiki.html?book=1</a> ",
"    <br>Example 1: <a href=\"wiki.html?book=PL\" target=\"_blank\">wiki.html?book=PL</a>",
"    <br>Example 1: <a href=\"wiki.html?book=pl\" target=\"_blank\">wiki.html?book=pl</a>",
"    <br>Example 2: <a href=\"wiki.html?bk=PL\" target=\"_blank\">wiki.html?bk=PL</a>",
"    <br>Example 3: <a href=\"wiki.html?b=pl\" target=\"_blank\">wiki.html?b=pl</a>",
"    <br>Example 4: <a href=\"wiki.html?@PL\" target=\"_blank\">wiki.html?@PL</a>",
"    <br>Example 4: <a href=\"wiki.html?@pl\" target=\"_blank\">wiki.html?@pl</a>",
"    <br>Example 5: <a href=\"wiki.html?1\" target=\"_blank\">wiki.html?1</a>",
" <br>Tip: Using the book index (like =1) is unreliable if hidden books are in the book list -- eg. book=1",
" <br>Tip: If no book or bad book name specified, default book \"kleckfiles\" is opened.",
"</li>",
"<li><b>Select page:</b> page=pageId, pageId",
"  <br>Example 1: <a href=\"wiki.html?@pl&page=cmdline\" target=\"_blank\">wiki.html?@pl&page=cmdline</a>",
"  <br>Example 2: <a href=\"wiki.html?@pl&cmdline\" target=\"_blank\">wiki.html?@pl&cmdline</a>",
"  <br>Tip: pageId is the page filename without the .js file extension. ",
"<br>You can view the file path by hovering the mouse over TOC item or going to the edit page.",
"</li>",
"<li><b>Special pages: </b>keywords available : edit|books|search",
"  <br>Example 1: <a href=\"wiki.html?@pl&edit\" target=\"_blank\">wiki.html?@pl&edit</a>",
"  <br>Example 3: <a href=\"wiki.html?@pl&books\" target=\"_blank\">wiki.html?@pl&books</a>",
"  <br>Example 3: <a href=\"wiki.html?@pl&search\" target=\"_blank\">wiki.html?@pl&search</a>",
"  <br>Example 2: <a href=\"chatpage.html?wiki\" target=\"_blank\">chatpage.html?wiki</a>",
"</li>",
"<li><b>Jump to bookmark: </b>jump=control_id",
"  <br>Example: <a href=\"wiki.html?bk=pl&codePage&jump=tocItem_4\" target=\"_blank\">wiki.html?bk=pl&codePage&jump=tocItem_4</a>",
"  <br>Jumps you to a control/section with that Id. Ctrl+click jump table (TOC) items to create a url containing the jump= link (opens in new tab).",
"</li>",
"<li><b>Search: </b>search=text, Use %20 for space in text if browser requires it. '2::text' to search book 2 for text. '*::text' to search all books for text. '*::' lists all pages in all books sorted by date modified, no text search, ",
"  <br>Example: <a href=\"wiki.html?search=lord\" target=\"_blank\">wiki.html?search=lord</a> - open default book and search for text",
"  <br>Example: <a href=\"wiki.html?search=2::lord\" target=\"_blank\">wiki.html?search=2::lord</a> - open default book and search book 2",
"  <br>Example: <a href=\"wiki.html?search=*::lord\" target=\"_blank\">wiki.html?search=*::lord</a> - open default book and search all books",
"  <br>Example: <a href=\"wiki.html?search=*::\" target=\"_blank\">wiki.html?search=*::</a> - open default book and list all files by date modified",
"  <br>Example: <a href=\"wiki.html?2&search=2::lord\" target=\"_blank\">wiki.html?2&search=2::lord</a> - open book 2 and search book 2",
"  <br>Example: <a href=\"wiki.html?2&search=lord\" target=\"_blank\">wiki.html?2&search=lord</a> - open book 2 and search (book 2)",
"  <br>",
"</li>",
'<li><b>Keywords (tags page): </b>?tags&jump=tagName, or #tagName ',
'  <br>Example: <a href=\"wiki.html?tags&jump=twins" target=\"_blank\">wiki.html?tags?jump=twins</a> - open tags page at #twins keyword info',
'  <br>Example: <a href=\"wiki.html#twins" target=\"_blank\">wiki.html#twins</a> - pseudo bookmark also goes to tags page',
"  <br>",
"</li>",
"</ul>"
];
